@@ -5,12 +5,12 @@ if(quiet) { options(warn=-1) }
 # if (is.list(db)) site <- tv.mysql(db, "tvhabita") else {
       if (missing(tv_home)) tv_home <- tv.home()
   site <- read.dbf(paste(tv_home, "Data", db[1], "tvhabita.dbf", sep = "/"))
+  bob <- data.frame(lapply(site, as.character), stringsAsFactors=FALSE)
   if (suppressWarnings(any(site < -1e+05, na.rm = TRUE))) 
-    print(c("WARNING! Values less than -100,000. \n", "WARNING! tvhabita.dbf may be corrupt. \n", "WARNING! Please correct by reexporting e.g. with OpenOffice."), quote = FALSE)
-         
+    print(c("WARNING! Values less than -100,000. \n", "WARNING! tvhabita.dbf may be corrupt. \n", "WARNING! Please correct by im- / exporting e.g. with OpenOffice."), quote = FALSE)
   if(length(db)>1) for(i in 2:length(db)) {
 	site.tmp <- read.dbf(paste(tv_home, 'Data', db[i],'tvhabita.dbf',sep='/'))
-	if(any(site$RELEVE_NR %in% site.tmp$RELEVE_NR)) stop('Datasets are using equal releve number(s), aborting!')
+	if(any(site$RELEVE_NR %in% site.tmp$RELEVE_NR)) stop('Found duplicate releve numbers, aborting!')
 	cols1 <- names(site)
 	cols2 <- names(site.tmp)
 	if (common.only){
@@ -26,6 +26,7 @@ if(quiet) { options(warn=-1) }
 		site <- rbind(site, site.tmp)
 	} 
   }
+for(i in names(site)[lapply(site, class) == 'factor']) site[,i] <- base:::iconv(site[,i], '437', '')
 
     ### Time
     if(any(is.na(site$DATE))) warning(sum(is.na(site$DATE)), ' releves without date. Not converted from factor to date format.') else {
@@ -47,9 +48,9 @@ if(quiet) { options(warn=-1) }
   ### Conversion of factors
   fac <- sapply(site, is.factor)
   if (!missing(iconv)) 
-      if (!is.null(iconv)) 
+      if (!is.null(iconv))
 	  for (i in (1:ncol(site))[fac & !(1:ncol(site)) %in% c(3,6,9)]) site[,i] <- type.convert(iconv(as.character(site[,i]), iconv[1], iconv[2]))
-  if (missing(iconv)) 
+  if (missing(iconv))
       for (i in c(1, 2, 4, 5, 7, 8, 10:ncol(site))) site[,i] <- type.convert(as.character(site[, i]),...)
   site$SURF_AREA[site$SURF_AREA==0] <- NA        
 ### 
